# About

`dbip-country-lite.mmdb` is provided by [dbip][dbip] under a
[ Creative Commons Attribution 4.0 International License][cc].

[dbip]: https://db-ip.com/db/lite.php
[cc]: http://creativecommons.org/licenses/by/4.0/
